@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.6'; # VERSION
+our $VERSION = '1.0.7'; # VERSION
 
 our %SCHEMAS;
 
@@ -150,7 +150,7 @@ Sah::Schema::TableDef - Sah schemas to validate TableDef
 
 =head1 VERSION
 
-This document describes version 1.0.6 of Sah::Schema::TableDef (from Perl distribution TableDef), released on 2015-09-06.
+This document describes version 1.0.7 of Sah::Schema::TableDef (from Perl distribution TableDef), released on 2016-03-08.
 
 =head1 SYNOPSIS
 
@@ -160,29 +160,23 @@ This document describes version 1.0.6 of Sah::Schema::TableDef (from Perl distri
 
 This module contains L<Sah> schemas to validate L<TableDef> specs.
 
-=head1 SCHEMAS
+=head1 SAH SCHEMAS
 
 =over
 
-=item * table_def
-
 =item * field_def
 
+=item * table_def
+
 =back
 
-=head1 SEE ALSO
-
-L<Sah>, L<Data::Sah>
-
-L<TableDef>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/TableDef>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-TableDef>.
+Source repository is at L<https://github.com/perlancar/perl-TableDef>.
 
 =head1 BUGS
 
@@ -192,13 +186,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah> - specification
+
+L<Data::Sah>
+
+L<TableDef>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
