@@ -1,7 +1,7 @@
 package TableDef;
 
-our $VERSION = '1.0.6'; # VERSION
-our $DATE = '2015-09-06'; # DATE
+our $VERSION = '1.0.7'; # VERSION
+our $DATE = '2016-03-08'; # DATE
 
 1;
 # ABSTRACT: Table data definition
@@ -18,7 +18,13 @@ TableDef - Table data definition
 
 =head1 VERSION
 
-This document describes version 1.0.6 of TableDef (from Perl distribution TableDef), released on 2015-09-06.
+This document describes version 1.0.7 of TableDef (from Perl distribution TableDef), released on 2016-03-08.
+
+=head1 SAH SCHEMAS
+
+=over
+
+=back
 
 =head1 HOMEPAGE
 
@@ -26,7 +32,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableDef>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-TableDef>.
+Source repository is at L<https://github.com/perlancar/perl-TableDef>.
 
 =head1 BUGS
 
@@ -36,13 +42,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah> - specification
+
+L<Data::Sah>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
